package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`\P`!````'",```````!``````````,"A````
M````!0```$``.``*`$``&P`:``8````$````0`````````!``````````$``
M````````,`(````````P`@````````@``````````P````0```!P`@``````
M`'`"````````<`(````````A`````````"$``````````0`````````#``!P
M!````&F@`````````````````````````````%,````````````````````!
M``````````$````%````````````````````````````````````,)@`````
M```PF``````````0`````````0````8```!XFP```````'BK````````>*L`
M``````#8!``````````%`````````!`````````"````!@```)";````````
MD*L```````"0JP```````#`"````````,`(````````(``````````0````$
M````E`(```````"4`@```````)0"````````1`````````!$``````````0`
M````````4.5T9`0```#8D````````-B0````````V)````````#L````````
M`.P`````````!`````````!1Y71D!@``````````````````````````````
M```````````````````````````0`````````%+E=&0$````>)L```````!X
MJP```````'BK````````B`0```````"(!`````````$`````````+VQI8B]L
M9"UL:6YU>"UR:7-C=C8T+6QP-C1D+G-O+C$`````!````!0````#````1TY5
M`'FA;21,8-]%W-/\R^;$&'G^Q227!````!`````!````1TY5```````$````
M#P````````!A````90``````````````40````4```````````````8`````
M```````````````[`````````!`````B````7@`````````O````20```$H`
M```\````60```&(````N````*P``````````````%@```$(````P````````
M``````!+````5````#H`````````50```&0````I````)P````<`````````
M#P`````````Y````6@```$@```!$`````````#8```!<````-0```"T````9
M``````````````!2````10```#@```!!````%````````````````````#X`
M```E````````````````````+````!(`````````"P```&,````;````````
M````````````&````#<````]````3``````````S`````````#\`````````
M`````%L`````````30````````!`````70```$8```!#````)@````T`````
M`````````````````````````````````````````````````````P``````
M````````````````````````````````````````````````````````````
M`&````!.```````````````.````&@````0`````````'@````````!0````
M```````````(`````````!\``````````````%\`````````*@``````````
M````6``````````1`````````&$````H````5@``````````````1P```#$`
M````````(0`````````C````(````!P````,``````````H```!3````````
M`!T`````````````````````````````````````````%0``````````````
M`````!<``````````````#(````D```````````````)````````````````
M``````````````!/````-``````````3`````@````````!7`````````!$`
M``!'````!`````@````@D!`!!4`$Q"@"`02`A@2$@HD``@D@!`B(@!!!N@`"
MB`````!'````2@```$T```!.````5@```%<```!9````6P```%P```!=````
M7P```&$```!B````9```````````````;L7?'\[>1RUK?YI\+L6;MM1DU'PA
M_^0.V7%8'.)'Q@&R`8MOK$OCP$+ZUX?"Y3\LNN.2?/JA;&"93\.;:PE#UF:O
MS&89?@J'0D75[(D'<--S4)_8,V+;[3[/TFP5C"7,##J7"_]A\F%_J9R;X*<"
M"FL:GE"CX/M)```````````````````````````````````````````#``T`
MD"$``````````````````.<"```1`````````````````````````*4"```2
M`````````````````````````'T!```2`````````````````````````(4`
M```2``````````````````````````P"```2````````````````````````
M`(P"```2`````````````````````````,D!```2````````````````````
M`````*X````2`````````````````````````(4"```2````````````````
M`````````*0````2`````````````````````````$@"```2````````````
M`````````````-8!```2`````````````````````````'T````1````````
M`````````````````)4````2`````````````````````````+`!```2````
M`````````````````````-<"```2`````````````````````````/P!```2
M`````````````````````````"$!```2`````````````````````````*$!
M```2`````````````````````````-,````2````````````````````````
M`,,````2`````````````````````````%@````2````````````````````
M``````$````@`````````````````````````!@!```2````````````````
M`````````+T"```2`````````````````````````!T````@````````````
M`````````````(X````2`````````````````````````,H````2````````
M`````````````````*\"```2`````````````````````````),!```2````
M`````````````````````'L````1`````````````````````````-D````6
M`````````````````````````%L!```2`````````````````````````.P`
M```2`````````````````````````(0!```2````````````````````````
M`$4!```2`````````````````````````%L"```2````````````````````
M`````,(!```2``````````````````````````<!```2````````````````
M`````````,@"```2`````````````````````````+4!```2````````````
M`````````````#8!```2`````````````````````````*H"```2````````
M`````````````````&\!```2`````````````````````````-`!```2````
M`````````````````````)<"```2`````````````````````````'8!```2
M`````````````````````````"\!```2`````````````````````````)H!
M```1`````````````````````````"T"```2````````````````````````
M`(L!```2`````````````````````````(T````2````````````````````
M`````$D````B`````````````````````````!@"```2````````````````
M`````````%,!```2`````````````````````````+T!```2````````````
M`````````````.`"```2`````````````````````````'D"```2````````
M`````````````````.<!```2`````````````````````````*H#```2````
M`````````````````````&P"```1`````````````````````````+4````2
M`````````````````````````/P````2`````````````````````````#D"
M```2`````````````````````````#<````2````````````````````````
M`)P````2`````````````````````````&(!```2````````````````````
M`````&H````2`````````````````````````/4!```2````````````````
M`````````+,#```2``T`SDL```````"D`````````$4$```2``T`&$4`````
M```&!0```````$0````2``T`D"$```````"*`0```````"H#```2``T`-#P`
M```````"`````````$@#```2``T`'DH```````"P`0```````&L$```2``T`
M-CP```````#6`0```````"L$```0`!<`4+```````````````````#L#```2
M``T`##X````````B`````````%X#```2``T`B$(```````!.`````````,L#
M```1``X`8$\````````$``````````@$```2``T`QDP```````#<````````
M`",$```2``T`1CL````````H`````````$`$```0`!<`>+``````````````
M`````%D$```2``T`5D0```````#"`````````(($```2``T`UD(```````!$
M`````````-H#```0`!8``+```````````````````((#```2``T`+CX`````
M```"`0```````/8#```0`/'_`+@``````````````````%($```0`!8`4+``
M`````````````````'@$```1`!8`2+`````````(`````````!,$```0`!8`
M4+```````````````````.`#```2``T`'",````````B`````````.<#```0
M`!8``+```````````````````#<$```2``T`<DP```````!4`````````-P#
M```@`!8``+```````````````````+\#```0`!<`>+``````````````````
M`)@#```2``T`/D0````````8`````````&P#```2``T`;CL```````#&````
M`````(X#```2``T`HDT```````"R`0```````(H$```2``T`,#\```````!8
M`P````````!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7TE435]R96=I
M<W1E<E1-0VQO;F5486)L90!?7VQI8F-?<W1A<G1?;6%I;@!?7V-X85]F:6YA
M;&EZ90!?7W)E9VES=&5R7V%T9F]R:P!?7W-T86-K7V-H:U]F86EL`%]?96YV
M:7)O;@!S=')N8VUP`&QS=&%T-C0`86-C97-S`&]P96YD:7(`<F5A9&1I<C8T
M`'-T<FQE;@!?7W-P<FEN=&9?8VAK`'5N;&EN:P!C;&]S961I<@!R;61I<@!0
M3%]C=7)R96YT7V-O;G1E>'0`8F]O=%]$>6YA3&]A9&5R`%!E<FQ?;F5W6%,`
M4&5R;%]N97=84U]F;&%G<P!R96%D;&EN:P!097)L7W-V7W-E='!V`&UE;6-H
M<@!097)L7W-V7W-E='!V;@!?7VUE;6UO=F5?8VAK`')E86QL;V,`9V5T<&ED
M`%]?;65M8W!Y7V-H:P!S=')C:'(`<W1R9'5P`'-T<G1O:P!S=')C;7``<W1R
M<F-H<@!M96UC<'D`<W1D97)R`%]?=F9P<FEN=&9?8VAK`&5X:70`;'-E96LV
M-`!R96%D`&UE;6-M<`!G971U:60`;6MD:7(`7U]E<G)N;U]L;V-A=&EO;@!?
M7V9P<FEN=&9?8VAK`&]P96XV-`!097)L7V=V7V9E=&-H<'8`4&5R;%]G971?
M<W8`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]M9U]S970`4&5R;%]S>7-?
M:6YI=#,`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?871F;W)K7VQO8VL`4$Q?
M9&]?=6YD=6UP`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7W!A<G-E`'!E<FQ?
M9&5S=')U8W0`<&5R;%]F<F5E`%!E<FQ?<WES7W1E<FT`<&5R;%]A;&QO8P!P
M97)L7V-O;G-T<G5C=`!P97)L7W)U;@!M96US970`7U]S=&%C:U]C:&M?9W5A
M<F0`;&EB<&5R;"YS;P!L:6)C+G-O+C8`;&0M;&EN=7@M<FES8W8V-"UL<#8T
M9"YS;RXQ`'!A<E]C=7)R96YT7V5X96,`<&%R7V)A<V5N86UE`%A37TEN=&5R
M;F%L<U]005)?0D]/5`!P87)?96YV7V-L96%N`'!A<E]C=7)R96YT7V5X96-?
M<')O8P!P87)?9&ER;F%M90!S:&%?9FEN86P`9V5T7W5S97)N86UE7V9R;VU?
M9V5T<'=U:60`<&%R7V-L96%N=7``7U]"4U-?14Y$7U\`7TE/7W-T9&EN7W5S
M960`7U]D871A7W-T87)T`%]?1$%405]"14=)3E]?`%]?9VQO8F%L7W!O:6YT
M97(D`'-H85]U<&1A=&4`7U]31$%405]"14=)3E]?`'AS7VEN:70`7U]B<W-?
M<W1A<G0`<VAA7VEN:70`7V5N9`!P87)?;6MT;7!D:7(`7V5D871A`'!A<E]S
M971U<%]L:6)P871H`'!A<E]F:6YD<')O9P!M>5]P87)?<&P`<&%R7V1I90!P
M87)?:6YI=%]E;G8`1TQ)0D-?,BXS-`!'3$E"0U\R+C,S`$=,24)#7S(N,C<`
M+W5S<B]L:6(O<&5R;#4O-2XT,"XP+W)I<V-V-C0M;&EN=7@M=&AR96%D+6UU
M;'1I+T-/4D4```````(``0`#``,``0`!``,``P`#``,``0`#``,``P`#``$`
M`0`!``,``P`#``,``0`#``$``0`$``,``0`#``,``0`#``$``P`#``$``P`!
M``$``P`!``,``P`#``$``P`#``,``0`#``0``P`!``,``P`#``$``P`#``$`
M`P`!``$`!0`#``,``P`#``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``P`$`P``$````$``
M``"TD98&```%`)<$```0````LY&6!@``!`"B!```$````(>1E@8```,`K00`
M```````!``$`#@,``!``````````AY&6!@```@"M!````````'BK````````
M`P`````````^(P```````("K`````````P````````#2(P```````(BK````
M`````P````````"8(P```````/BO`````````P````````"0(0````````"P
M`````````P``````````L````````!BP`````````P````````#`4```````
M`""P`````````P````````"8D````````"BP`````````P````````"@D```
M`````#"P`````````P````````"HD````````#BP`````````P````````"P
MD````````$BP`````````P`````````H4P```````*"O`````````@````(`
M`````````````*BO`````````@````P``````````````+"O`````````@``
M``X``````````````+BO`````````@```!@``````````````,"O````````
M`@```!L``````````````,BO````````"P```"$``````````````-"O````
M`````@```",``````````````-BO`````````@```"8``````````````."O
M`````````@```#(``````````````.BO`````````@```#8`````````````
M`/"O`````````@```#X``````````````-"M````````!0````,`````````
M`````-BM````````!0````0``````````````."M````````!0````4`````
M`````````.BM````````!0````8``````````````/"M````````!0````<`
M`````````````/BM````````!0````@```````````````"N````````!0``
M``D```````````````BN````````!0````H``````````````!"N````````
M!0````L``````````````!BN````````!0````T``````````````""N````
M````!0````\``````````````"BN````````!0```!```````````````#"N
M````````!0```!$``````````````#BN````````!0```!(`````````````
M`$"N````````!0```!,``````````````$BN````````!0```!0`````````
M`````%"N````````!0```!4``````````````%BN````````!0```!8`````
M`````````&"N````````!0```!<``````````````&BN````````!0```!D`
M`````````````'"N````````!0```!H``````````````'BN````````!0``
M`!P``````````````("N````````!0```!T``````````````(BN````````
M!0```!X``````````````)"N````````!0```!\``````````````)BN````
M````!0```"(``````````````*"N````````!0```"0``````````````*BN
M````````!0```"4``````````````+"N````````!0```"<`````````````
M`+BN````````!0```"@``````````````,"N````````!0```"D`````````
M`````,BN````````!0```"H``````````````-"N````````!0```"L`````
M`````````-BN````````!0```"P``````````````."N````````!0```"T`
M`````````````.BN````````!0```"X``````````````/"N````````!0``
M`"\``````````````/BN````````!0```#````````````````"O````````
M!0```#$```````````````BO````````!0```#,``````````````!"O````
M````!0```#0``````````````!BO````````!0```#4``````````````""O
M````````!0```#<``````````````"BO````````!0```#@`````````````
M`#"O````````!0```#D``````````````#BO````````!0```#H`````````
M`````$"O````````!0```#L``````````````$BO````````!0```#P`````
M`````````%"O````````!0```#T``````````````%BO````````!0```#\`
M`````````````&"O````````!0```$```````````````&BO````````!0``
M`$$``````````````'"O````````!0```$(``````````````'BO````````
M!0```$,``````````````("O````````!0```$0``````````````(BO````
M````!0```$4``````````````)"O````````!0```$8``````````````)>3
M```S`\-!`[X#_A,#0_V3@@/^$U,3`(.R@@!G``X`%YX```,^#OUG`PX`$P``
M`!>>```#/H[\9P,.`!,````7G@```SX._&<##@`3````%YX```,^COMG`PX`
M$P```!>>```#/@[[9P,.`!,````7G@```SZ.^F<##@`3````%YX```,^#OIG
M`PX`$P```!>>```#/H[Y9P,.`!,````7G@```SX.^6<##@`3````%YX```,^
MCOAG`PX`$P```!>>```#/@[X9P,.`!,````7G@```SZ.]V<##@`3````%YX`
M``,^#O=G`PX`$P```!>>```#/H[V9P,.`!,````7G@```SX.]F<##@`3````
M%YX```,^CO5G`PX`$P```!>>```#/@[U9P,.`!,````7G@```SZ.]&<##@`3
M````%YX```,^#O1G`PX`$P```!>>```#/H[S9P,.`!,````7G@```SX.\V<#
M#@`3````%YX```,^CO)G`PX`$P```!>>```#/@[R9P,.`!,````7G@```SZ.
M\6<##@`3````%YX```,^#O%G`PX`$P```!>>```#/H[P9P,.`!,````7G@``
M`SX.\&<##@`3````%YX```,^CN]G`PX`$P```!>>```#/@[O9P,.`!,````7
MG@```SZ.[F<##@`3````%YX```,^#NYG`PX`$P```!>>```#/H[M9P,.`!,`
M```7G@```SX.[6<##@`3````%YX```,^CNQG`PX`$P```!>>```#/@[L9P,.
M`!,````7G@```SZ.ZV<##@`3````%YX```,^#NMG`PX`$P```!>>```#/H[J
M9P,.`!,````7G@```SX.ZF<##@`3````%YX```,^CNEG`PX`$P```!>>```#
M/@[I9P,.`!,````7G@```SZ.Z&<##@`3````%YX```,^#NAG`PX`$P```!>>
M```#/H[G9P,.`!,````7G@```SX.YV<##@`3````%YX```,^CN9G`PX`$P``
M`!>>```#/@[F9P,.`!,````7G@```SZ.Y6<##@`3````%YX```,^#N5G`PX`
M$P```!>>```#/H[D9P,.`!,````7G@```SX.Y&<##@`3````%YX```,^CN-G
M`PX`$P```!>>```#/@[C9P,.`!,````7G@```SZ.XF<##@`3````%YX```,^
M#N)G`PX`$P```!>>```#/H[A9P,.`!,````7G@```SX.X6<##@`3````'7&&
M[*;DJH>BZ,K@3OR7E```@[0DX"[H,N0,"#``:`@^SIQ@/O2!1^_PG_<7E@``
M`S;&WK*%%Y4```,U)>'O('!8EY<``(.WY^&#QP<`\<^7EP``@[>'WA>4```3
M!`3GDI>88W))@T>G2QL%20`.!9/G-P`C#?=*[_"?[<)E\D<(Y)AA#2FJAACA
M%S<``!,'YP\8Y1>7```#-T?B&.D7-P``$P<G#QCM!4=C6?<,&X@W`$*&H041
M1XAADQ<W`+:7!2>(XZ$%XQD'_YL'!@".!PALMI<!1TJ&EQ4``).%15XCL`<`
M[_#?O#W%"&R3"4$"[_`?W"J)SH47-0``$P6%W.\0X#HIS0AL[_"?MN_P7\TB
M=YQ@N8\!1[WGYF!&9*9DXGE*A09I)6&"@._P?\@7E```$P2DV0CL(<7O\'_1
MEY<``(.WI\^%9C.'1P`88S:7(PL'DC&W"&SO\)^]>;<(:`'%[R#0#46WSH47
M-0``$P7ES>\0P#,(Z%G5Y;>11X&_!47O\/^Y[_"_Y0``[P`@`JJ'%Y4```,U
M9<V"93``$W$!_X%&`4<*B._PG^`"D)>1``"3@2%,@H```!>5```3!670EY<`
M`).'Y\]CB*<`EY<``(.WI\61PX*'@H`7E0``$P5%SI>5``"3A<7-B8V3US5`
M_9&^E86%F<67EP``@[=GPY'#@H>"@$$1(N`7E```$P1$RX-'!``&Y(7CEY<`
M`(.WQ\.1QQ>5```#-:7$@I?O\+_XA4<C`/0`HF`"9$$!@H!IOQ,!`=0C.($J
M(SP1*B,TD2HC,"$K(SPQ*2,X02D7E````S0$NS0`P6Y]7QQ@(S3Q*(%'DPB%
M`Y,"A0<VB!-?#P*W#_\`DXX.\`.V"`!!"*$(DU4&`A,7A@&3$X8`DU>&`A->
MA@"35(8#$Y.%`3-WYP&S\_,!L_?7`3-G=P`S?MX!Q8\S<^,!H@4S9\<!&U:&
M`;/G9P"S]?4!48_-CR,XZ/XC//C^XY(2^_U5QG]F?PIGXFX"?B)SPGAB>(9C
MDX0&((&1$:"R@[!BG&*Z@J$&L8^SQ_<!L\?7`1.7%P#]@UV/;8^X_OJ/\HX6
MCQJ.1H/"B!Z(XYF6_(,^!0"B;P,X!0$#,X4`@SB%`0,^!0(WAX):$P>7F9/7
MO@$3EEX`78ZZGQ-?(P"3%^,!;8[RG[-&&`&SY^<!L_9F`'Z6PF\S_[<`L\86
M`3:6LT;H`6V.L_;6`;J?DQ)6`)-4M@'&G[/&!@'^EK/OD@`3V2X`DY/N`?Z6
MXF^SXR,!L\=W`/&/NI_MCK/'YP'"GY.45@`3V;8!DQ+F`?Z7"8*"?[/BP@`S
MYB0!LI<SQE,`NI^S\[,`=8[MCWZ?,T9V`).45P`3V;<!DY_F`7J6B8(B?[/O
MWP"SYB0!-I:SQO(!;8ZS\K(`_8XZGQZ?DQ16`!-9M@&SQE8`DY/G`8F#L^/S
M`/J6L^<D`;Z6,_^V`,)VL\=_`/&/L_^_`+J6EI:3%%\`$UF_`;/']P&VE[/F
M)`&VEY,2Y@$)@K/BP@`S]K<`XG>SQE,`L_;F`;/SLP"ZE_Z7DQ16`!-9M@&S
MQG8`OI:SYR0!OI:3'^\!$U\O`+/O[P$S_[8`AF:SQ_(!\8^S\K(`NI:>EI,4
M7P`36;\!L\=7`+:7L^8D`;:7DQ/F`0F"L^/#`#/VMP"F9[/&?P"S]N8!L_^_
M`+J7EI>3%%8`$UFV`;/&]@&^EK/G)`&^EI,2[P$37R\`L^+B`3/_M@#&9K/'
M4P#QC[/SLP"ZEOZ6DQ1?`!-9OP&SQW<`MI>SYB0!MI>3'^8!"8*S[\\`,_:W
M`.9GL\;R`;/VY@&S\K(`NI>>EY,45@`36;8!L\96`+Z6L^<D`;Z6DQ/O`1-?
M+P"SX^,!,_^V`(9VL\=_`/&/L_^_`+J6EI:3%%\`$UF_`;/']P&VE[/F)`&V
MEY,2Y@$)@K/BP@`S]K<`IG>SQE,`L_;F`;/SLP"ZE_Z7DQ16`!-9M@&SQG8`
MOI:SYR0!OI:3'^\!$U\O`+/O[P$S_[8`QG:SQ_(!\8^S\K(`NI:>EI,47P`3
M6;\!L\=7`+:7L^8D`;:7DQ/F`0F"L^/#`#/VMP#F=[/&?P"S]N8!L_^_`+J7
MEI>3%%8`$UFV`;/&]@&^EK/G)`&^EI,2[P$37R\`L^+B`3/_M@"*9K/'4P#Q
MC[/SLP"ZEOZ6DQ1?`!-9OP&SQW<`MI>SYB0!MI>3'^8!"8*S[\\`,_:W`*IG
ML\;R`;/VY@&S\K(`NI>>EY-4M@&3$U8`L\96`!,9[P&^EA-?+P"SYY,`RF,S
M;^D!OI:SQ^\![8ZS_[\`NI/QCYZ2D]2V`;/']P&3DU8`L^.3`):7ZF23$N8!
M"8*SXL(`GI?MCS-&7P"ZE#-_OP`3V;<!=8Z3DU<`II\S1N8!L^,C`;/SLP!^
MEI.?Y@&)@AZ6L^_?``IYLW2V`+/&\@']CK/RL@"3DU0`D]FT`3J9,\=6`+/F
M,P&3D^<!B8.SX_,`2I^SQW\`[8YZE[&/*G8S#]<`-_?9;A,'%[JS>;\`$]FY
M`3J6DY99`!:6[8^SYB8!LI?MCKZ6DY+D`<IWB8"SXI(`,_FV`#/&4P"S_[\`
MDU2Y`;J7,T_F`1,660`S?[\`_I=%COJ7;8X^EI.?Z0'J=Y/9*0"S[S\!LW2V
M`#//\@&S\[,`D]FT`;J7,T_?`).65``S?[\`GI>SYC8!^I?MCKZ6$Q_I`8YG
M$UDI`#-O+P&S\[8`,\GO`;/YL@"ZE[-"R0`3V;,!$Y93`+/RL@#.ES-F)@&6
MEVV./I:3DN0!KF>)@+/BD@`S25\`LW2V`+/YOP"ZE[-/V0`3V;0!DY94`+/_
MOP#.E[/F)@'^E^V.OI:3G^,!SF>3TR,`L^]_`#/)\@&S\[8`LWF_`+J7,T_)
M`!/9LP$3EE,`,W^_`,Z7,V8F`?J7;8X^EA.?Y`'N9XF`,V^?`#/)[P&S=+8`
ML_FR`+J7LT+9`!/9M`&3EE0`L_*R`,Z7L^8F`9:7[8Z^EI.2XP&.=Y/3(P"S
MXG(`,TE?`+/SM@"S^;\`NI>S3\D`$]FS`1.64P"S_[\`SI<S9B8!_I=MCCZ6
MDY_D`:YWB8"S[Y\`,\GR`;-TM@"S>;\`NI<S3]D`$]FT`9.65``S?[\`SI>S
MYB8!^I?MCKZ6$Y_C`<YWD],C`#-O?P`SR>\!L_.V`+/YL@"ZE[-"R0`3V;,!
M$Y93`+/RL@#.ES-F)@&6EVV./I:3DN0![G>)@+/BD@`S25\`LW2V`+/YOP"Z
ME[-/V0`3V;0!DY94`+/_OP#.E[/F)@'^E^V.OI:3G^,!DF>3TR,`L^]_`#/)
M\@&S\[8`LWF_`+J7,T_)`!/9LP$3EE,`,W^_`,Z7,V8F`?J7;8X^EA.?Y`&R
M9XF`,V^?`#/)[P&S=+8`L_FR`+J7LT+9`!/9M`&3EE0`L_*R`,Z7L^8F`9:7
M[8Z^EI.2XP'29Y/3(P"SXG(`,TE?`+/SM@"S^;\`NI>S3\D`$]FS`1.64P"S
M_[\`SI<S9B8!_I=MCCZ6DY_D`?)GB8"S[Y\`,\GR`;-TM@"S>;\`NI<S3]D`
M$]FT`9.65``S?[\`SI>SYB8!^I?MCKZ6$Y_C`9)WD],C`#-O?P`SR>\!L_.V
M`+/YL@"ZE[-"R0`3V;,!$Y93`+/RL@#.ES-F)@&6EVV./I:3DN0!LG>)@+/B
MD@`S25\`LW2V`+/YOP"ZE[-/V0`3V;0!DY94`+/_OP#.E[/F)@'^E^V.OI:3
MG^,!TG>3TR,`L^]_`#/YM@"SP_(!LWF_`+J7,\_#`)-3N0$3%ED`,W^_`,Z7
M,V9V`&V.^I<SC\<`DY/D`?)WB8"SXY,`,\9_`+-TOP"S\K(`NI>QCNV.D]FT
M`9:7DY)4`+:7L^8R`;:7$Q;I`99F$UDI`#-F)@$SR<,`L_*W`+/_OP"S1^D!
MNI:3V;(!_I83F5(`L_^W`#-I.0'^ELJ6$Y_D`8F`,V^?`#?WQB.S=+8`_5?U
MC;9F@9,*!Q,'Q\VS?_\`,V;F`3/Y]`&ZEC-V5@"S\_,`MI.3V;4!,V8F`1.9
M50`>EK-C.0$>EK-S]@"3EN(!5F:3TB(`L^96`+/R]@`S;]\`,_E?`#J6,W^_
M`+*4D]FS`3-O+P$3F5,`)I^S9#D!$Y;E`2:?B8'V9$V.LW7V`-&.,W__`#/Y
ML@"S]G8`NI3^E)-9OP&SYB8!$QE?`*:6LV0Y`1.:XP&3WR,`II:6=+-O^@&S
M\_\`,V;V`?V.,_EU`+J4,W;F`::2,V8F`9.45@`3V;8!L^0D`1:6DQGO`2:6
M$U\O`+9T,^_I`;-R_P"S[^\!?8XS^5,`L__?`+J4L^\O`:Z4$QE6`)-9M@&3
ME>8!B8+5C;.&GP"S;SD!_I;6?[/T]0`S;[\`_8XS^9(`NI\S?\\`,V\O`?Z3
M$YE6`)/9M@&3'^8!"8*S[\\`,P9_`#-O.0%ZEG9_L_/_`+/E]0%]CC/Y=``Z
MG_6-L^4E`?J2$QE6`)-9M@$3G^8!B8(S;]\`LX95`+-E.0&NEIIELW+_`+/O
M[P']CC/Y4P"ZE;/_SP"S[R\!KI03F58`D]FV`9,5Y@$)@M&-,X:?`+-O.0%^
MEKIOL_3U`#-OOP!]CC/YD@"ZGS-_WP`S;R\!_I,3&58`DUFV`9.?Y@&)@K/O
MWP"S!G\`,V\Y`?J66F^S\_\`L^7U`?V.,_ET`#J?\8VSY24!^I(3F58`D]FV
M`1,?Y@$)@C-OSP`SAE4`LV4Y`2Z6^F6S<O\`L^_O`7V.,_E3`+J5L__?`+/O
M+P&NE!,95@"36;8!DY7F`8F"U8VSAI\`LV\Y`?Z6FG^S]/4`,V^_`/V.,_F2
M`+J?,W_/`#-O+P'^DQ.95@"3V;8!DQ_F`0F"L^_/`#,&?P`S;SD!>I8Z?[/S
M_P"SY?4!?8XS^70`.I_UC;/E)0'ZDA,95@"36;8!$Y_F`8F",V_?`+.&50"S
M93D!KI;:=;-R_P"S[^\!_8XS^5,`NI6S_\\`L^\O`:Z4$YE6`)/9M@&3%>8!
M"8+1C3.&GP"S9#D!)I;Z=+/_]0`S;[\`?8XS^?(!,W_?`+J4,V\O`9Z4$QE6
M`)-9M@&3D^8!B8*SX],`LP:?`+-D.0$>:3/_\P"SY74`II;QC;/T[P$ZF?V.
M%IG%C9.95@`3VK8!DU(F`),4Y@'*E3YIL^14`#/F20&S\O0`LI4SYI,`=8ZS
M\_4`.IFS=5\`?IF3F5,`$]JS`4V.D]\F`).5Y@%*EK/F20&SY?4!-I:SYK0`
MLW3V`%YFL__U`#/Y\@&S]G8`.I9ZEK/F)@$3GU0`$]FT`3-O+P&REGYI$Y;C
M`9/3(P`S9G8`LW/V`/J6T8W]CC/Z?P#EC3J9$Y]6`)/9M@$6F;/E10&S8C\!
MRI43WR0`$YGD`;-DZ0$>?[/R\@"6E46.L_+T`#/Y]0`S^E,`=8XZGY-9N0$3
M%UD`?I\S9D8!LV\W`7J6DYGF`1/?)@`S[^D!L\;D`;/__P"MCC>WF#*^=;*?
M"@<3!V<=L_G_`)/4N0&ZE1.660">E?V.18Z3$^D!$UDI`+/C(P%]CJZ6LX7&
M`#-&?P`S1O8!WG^S]/4`$]FT`;J?DY94`):??8ZSYB8!_8Y^EC:6DY_I`?YV
MD]DI`+/O/P$S>?8`L\+S`;-Y_P"ZEC//L@"34KD!DQ59`#-__P#.EK/E50#Z
MEOV-MI43G^0!@S8!((F`,V^?`+/"[P&S]/4`L_/S`)/9M`&ZEK/"P@`3EE0`
ML_+R`)Z6,V8V`9:6?8XVEI,2Z0&#-H$@$UDI`+/B(@&S<_8`,TE?`+/Y_P"Z
MEK-/N0`3V;,!DY53`+/__P#.EK/E)0'^EOV-MI63G^0!@S8!(8F`L^^?`#/)
M\@&S]/4`LWG_`+J6,T_)`!/9M`$3EE0`,W__`,Z6,V8F`?J6?8XVEA.?XP&#
M-H$AD],C`#-O?P`SR>\!LW/V`+/Y\@"ZEK-"N0`3V;,!DY53`+/R\@#.EK/E
M)0&6EOV-MI63DN0!@S8!(HF`L^*2`#-)7P"S]/4`L_G_`+J6LT_)`!/9M`$3
MEE0`L___`,Z6,V8F`?Z6?8XVEI.?XP&#-H$BD],C`+/O?P`SR?(!LW/V`+-Y
M_P"ZEC-/N0`3V;,!DY53`#-__P#.EK/E)0'ZEOV-MI43G^0!@S8!(XF`,V^?
M`#/)[P&S]/4`L_GR`+J6LT+)`!/9M`$3EE0`L_+R`,Z6,V8F`9:6?8XVEI.2
MXP&#-H$CD],C`+/B<@`S25\`LW/V`+/Y_P"ZEK-/N0`3V;,!DY53`+/__P#.
MEK/E)0'^EOV-MI63G^0!@S8!)(F`L^^?`#/)\@&S]/4`LWG_`+J6,T_)`!/9
MM`$3EE0`,W__`,Z6,V8F`?J6?8XVEA.?XP&#-H$DD],C`#-O?P`SR>\!LW/V
M`+/Y\@"ZEK-"N0`3V;,!DY53`+/R\@#.EK/E)0&6EOV-MI63DN0!@S8!)8F`
ML^*2`#-)7P"S]/4`L_G_`+J6LT_)`!/9M`$3EE0`L___`,Z6,V8F`?Z6?8XV
MEI.?XP&#-H$ED],C`+/O?P`SR?(!LW/V`+-Y_P"ZEC-/N0`3V;,!DY53`#-_
M_P#.EK/E)0'ZEOV-MI43G^0!@S8!)HF`,V^?`#/Y]0"SQ.\!L_GR`+J6L\+$
M`)-4N0$3%ED`L_+R`,Z618Z6EGV.-I:3E.,!@S:!)I/3(P"SY'0`LT*?`+-S
M]@"S^?\`NI:SS[(`D]*S`9.54P"S__\`SI:SY54`_8W^EK./M@"3$ND!@S8!
M)Q-9*0"SXB(!L\54`#/Y_P`S?_\`DUFY`;J6L8T3%ED`_8WZEC-F-@%]CJZ6
MLX7&`!.?XP$#-H$GD],C`#-O?P"SQN(!L_/U`/V,.I:SQO8!_8XFEI/9LP&3
ME%,`-I:SYC0!-I:#-@$HDQ_I`1-9*0"S[R\!NI:S1/\!,W?V`/:6L_+R`#/&
MM`!]CI,55P"37K<!EI:REC/FU0&3E>,!D],C`+*6L^5U`/V..I,S!L\!,X<%
M`;.%'P%]CQ3A_8VS=O,`\8\8Z1SQ%.4,[0,W@2@<8+F/`4>%XX,P@2L#-`$K
M@S2!*@,Y`2J#.8$I`SH!*1,!`2R"@._@?[,Y<0;\(OA9Q5K@EX<``(.WAY8#
MNP<`8P$+"$KP3NQ2Z(-'!0"JB2Z**HD3!]`#I<MCAN<`@T<9``4)_?L["3E!
M`S0+`#G,)O16Y-J$DPK0`TJ&SH4BA>_@S_BS!R0!">6#QP<`8X!7`X!DH01U
M\*)T`GGB:4)JHFH":^)P(H5"="%A@H"SA&1!C80%"2,@F@!*E/&_`435MP)K
M`43YOP%)1;<">>)I0FH":\&_<7$B\2;M!O67A```@[3DBBP`G&`^Y8%'*H3O
MX-^8#>'B1[UF$6?UCV.%YP`I9V.:YP")12*%[^`/^!,U%0`1H`%%*F><8+F/
M`4>1YZIP"G3J9$UA@H#OX!^C,7%.[0;]EXD``(.Y:86#MPD`/N6!1QG%(OF#
M1P4`*H2)[TIT*F>#MPD`N8\!1V.7!PSJ<.II*6&"@";U2O'OX/^<JH19R2:%
M[^!/[TG!@T8U`1,)-0&;AB;]@>:#1AD`_=(#1S4!&P<G_27/(H52Z>_@S^HJ
MBDJ%[^!/ZCL*J@`)*E*%[^"/ZLJ'(H>7%@``DX:&>5*&B44JB>_@/Y,L`$J%
M[^"O]OU78PCU`.)'O6819_6/8X#G!$J%[^`O\4J%[^#?@":%2FKOX$_G2?$F
MA>_@S_0BA>_@;^Y*=*IT"GF1MP-'&0`;!R?]2?,#1RD`.=NMOTJ%[_"_\-&W
M(ODF]4KQ4NGOX)^201$BX!=T```#-(1W!N279@``DX9FAK,'1`"(8Q=V```#
M-H9VEQ4``).%!7#OX)^*$I0(8`)DHF`7)P``$P?'J(%'NH87%@``$P;F&)<5
M``"3A85O00%OX._R77%6[/UWA6K]<N$7$X<*`:+@)OQ*^$[T4O"&Y#Z7%I&N
MB;,%)P`3AXH`"I<%9!=Y```#.<EL*HH3!O3_%Q4``!,%96R#-PD`'..!1^_@
M[^.;!`4`8UZ0`!.'"@$*ES,$AT";A_3_/I0#1X3_*>.=[Y=W``"#MR=K3H;2
MA9*7B&/OX*_;A6>A!XJ7F&.#-PD`N8\!1[GGA6(6D:9@!F3B=$)YHGD">N)J
M86&"@+Z$_7<%9^$700<^ES,$)P`FAI,%\`(BA>_@;^]%U9=W``"#MX=EIH8B
MAI*7B&/2A>_@[^=5M^_@C_Y9<:+PINS*Z-+@AO3.Y%KX7O2#QP4`%WD```,Y
MZ5^JA).'-_R3MQ<`,X3U`"*%@S<)`#[D@4?OX._)*HI,`":%[_`_QWG)JHGO
MX,_(8W9%"Q)+EWL``(.[*UT."P/'!`"FAY,&T`-C#`<28P;7``/'%P"%!WW[
MA9^#N0L`$P4J`#Z5VIGOX`_&(["I`#'%`[<+`(/'!``3A10`6I<48Q,&T`,C
M@/8`@>N]H(-'!0`%!:,`]P"MPS:'A0;CF,?^DP;0`Y,'%P`C`-<``T<$`(4'
M!02CC^?^=?LB9X,W"0"YCP%'^>.F<`9TYF1&::9I!FI">Z)[96&"@(-'!`"%
M"04$HX_Y_O';@T<$`(4)!02CC_G^_?/1MS:'7;=6_&+P9NR7>P``@[M+4(.\
M"P"#MPP`K<OFAX%)F&?.AJ$'A2EE_XTFDYHV`)=W``"3AV=8F$,%[P5'5H68
MP^_@S[@JC#')$YLY`-:&6H;FA>_@K\LCL(L!FX<9`(X'/IPC,`P`XGH"?.)L
M3L+9O=:%9H7OX(_9(["K`"J,$<T3FSD`V;^!1^&]P4J!246W5OQB\&;L[^!O
MX^)Z`GSB;`6WEW<``(.W)TB75@``DX8F5Q=V```#-J9'DI>(8Y<5``"3A>5`
M;^!OVUUQ)OSY<HEDAN2BX$KX3O12\!.'A`$6D0J7EWD``(.YB4&#MPD`'..!
M1^_@C[_]=\$7DX8$`KZ6,X0F``5F*H>7%P``DX>G0)<6``"3AJ9`!0:)12*%
M[^#/U/EUH163AP0"KI>SA"<`(H4%9J:%[^!/M1L$!0`!26-!!`(;"A0`4H7O
MX`^H*HD)R2*&TH:FA4J4[^`/UB,`!`")9^$'BI>88X.W"0"YCP%'@>^)8A:1
MIF!*A09DXG1">:)Y`GIA88*`[^`/U"V_A6;]=U%Q_7*3AT?W$X<&":+QINW*
MZ6+QAO7.Y=+A5OU:^5[U9NUJZ3Z7%I$NA+,%)P`3AX8("I<7?````SPL,RJ)
M@S<,`!SC@4<7%0``$P6%->_P?YNJA),%\`)*A>_@S[@AQ1<5```3!>4TRH7O
M\)_.2H6%9Y.'APB*EYAC@S<,`+F/`4=CE@<4A6(6D:YP#G3N9$YIKFD.:NIZ
M2GNJ>PI\ZFQ*;6UA@H`BA>_@[[:7%0``DX4E,>_@+Y(JA%W1A6?]>>$9$X<'
M"4Z7LPDG`!.'!PF3AP<)BI>%:GUZLXQ708-'!``3"HKW4I>7&P``DXOK+1<;
M```3"^LM,PHG`,G+D<2BA2:%[^`OIC7%(H7OX*^1DP?U_Z*7*HV3!O`"8VCT
M`#&H(X`'`/T78P;T``/'!P#C"=?^(H7OX`^/*HU*A>_@CXYJE04%XWU5\8E%
M2HC>AR*'VH8%9DZ%[^#OM]*%3H7OX&^;`>F#IXSXO68A9_6/8X_G`I<5``"3
MA:4D`47OX(^%*H3C#@7L@T<$`*W[D<2#QP0`FX<G_9G'!4T7%```$P2D'V&_
M@\<4`.G7_;>%14Z%[^!/BUW]SH47%0``$P5%'^_P'[E.A>_@[Z15M>_@C[9!
M$9,%\`(BX`;D*H3OX(^F&<$3!!4`(H4"9*)@00%OX&^B>7&%9_UR2N@&]"+P
M)NP3AX<`%I$7>0```SGI%0J7@S<)`!SC@4=-P8-'!0"JA,G/[^`O@!,&%0"%
M9RJ$8^_'"GUW81?!![J7,X<G`*:%.H7OX"^0DP?T_ZJ7DP;P`F-H]0`1J".`
M!P#]%V.&IP`#QP<`XPG7_GUUA6=A%<$'JI<SA"<`DP7P`B*%[^"/G`W-8V*D
M!GUUA6=A%<$'JI<SA2<`[^`/F(5GH0>*EYAC@S<)`+F/`4>AYX5B%I&B<`)T
MXF1":45A@H"%9Z$'BI>88X,W"0"YCP%'G>.%8A:1HG`"=.)D0FD7%0``$P7%
M"T5A;^`ODR,`!0!QOP%%;;?OX$^D.7$B^";T2O!.[`;\EW0``(.T1`:<8#[D
M@4=``!<9```3"4D,EWD``(.YR06BA4J%[_#O[17!$D>#MPD`#@>ZEYAGF.-E
MUYAKH0>8XVW_HH5*A>_PS^ME\1<9```3"8D)EWD``(.Y"0*BA4J%[_`OZA7!
M$D>#MPD`#@>ZEYAGF.-EUYAKH0>8XVW_HH5*A>_P#^AE\1<9```3"4D&EWD`
M`(.Y2?ZBA4J%[_!OYA7!$D>#MPD`#@>ZEYAGF.-EUYAKH0>8XVW_HH5*A>_P
M3^1E\1<9```3"8D#EWD``(.YB?JBA4J%[_"OXA7!$D>#MPD`#@>ZEYAGF.-E
MUYAKH0>8XVW_HH5*A>_PC^!E\1<9```3"4D`EWD``(.YR?:BA4J%[_#OWA7!
M$D>#MPD`#@>ZEYAGF.-EUYAKH0>8XVW_HH5*A>_PS]QE\1<9```3"8G]EWD`
M`(.Y"?.BA4J%[_`OVQ7!$D>#MPD`#@>ZEYAGF.-EUYAKH0>8XVW_HH5*A>_P
M#]EE\1<9```3"4GREWD``(.Y2>^BA4J%[_!OUQ7!$D>#MPD`#@>ZEYAGF.-E
MUYAKH0>8XVW_HH5*A>_P3]5E\1<9```3"0GWEWD``(.YB>NBA4J%[_"OTQ7!
M$D>#MPD`#@>ZEYAGF.-EUYAKH0>8XVW_HH5*A>_PC]%E\1<9```3"4GTEWD`
M`(.YR>>BA4J%[_#OSQ7!$D>#MPD`#@>ZEYAGF.-EUYAKH0>8XVW_HH5*A>_P
MS\UE\1<9```3"8GQEWD``(.Y">2BA4J%[_`OS!7!$D>#MPD`#@>ZEYAGF.-E
MUYAKH0>8XVW_HH5*A>_P#\IE\1<9```3"4GDEWD``(.Y2>"BA4J%[_!OR!7!
M$D>#MPD`#@>ZEYAGF.-EUYAKH0>8XVW_HH5*A>_P3\9E\:*%%Q4``!,%Y>KO
M\$_%JH49Q1<5```3!>7G[_`O^:*%%Q4``!,%A>KO\&_#JH49Q1<5```3!07K
M[_!/]Z*%%Q4``!,%)>OO\(_!JH4%S1<5```3!:7:[_!O]2)GG&"YCP%'J>-"
M=.)PHG0">>)IEQ4``).%I>H7%0``$P6EWB%A;_#/\J*%%Q4``!,%I>?O\`^]
MJH5YT1<5```3!:7>[_#O\&6_[]#?[@$1(N@&[!=T```#-"313``7%0``$P6%
MW!Q@/N2!1^_PC[D5P8-'!0`!18G'DX<'_3,U\``B9QQ@N8\!1YGGXF!"9`5A
M@H`!1?6W[]#_Z1UQ!NPJCA=U```#-470"&$3`X$"+O0R^#;\ON2ZX,+HQNR7
M=P``@[>'RIJ&<H:)19AC.N0!1QK@[]`_OA,%\`_OT+^Y67&B\,%R063.Y-+@
M9NR&]*;LRNA6_%KX7O1B\!,'A``6D0J7EWP``(.\+,:#MPP`'..!1PE&@44J
MBN_0W\F3"?7_$]?Y0T&3LX?I`,(7P9.9C[.)^4!CQPD*P73!%),'!`'!:Z:7
M_5JSA"<`H0L=3!=Y```3">G'07L!1LZ%4H7OT'_%8PA5"5Z&IH52A>_0G]$!
M)6,*50=C<ZP&814SA*0`8W:4`*&H?11C:I0$(4;*A2*%[]`_OV7YP7=!9\$7
M00<^E[,')P`S!?1`3I7!9Z$'BI>88X.W#`"YCP%'J>/!8A:1IG`&=.9D1FFF
M:09JXGI">Z)[`GSB;&5A@H#:F>.=:?=]5>&W%Q4``!,%Y<[O\-_J%Q4``!,%
M)<WO\!_J[]!_TT$1!N3OT/^@`27OT)_+$<$(8:)@00&"@#EQ)O1*\`;\%WD`
M``,Y*;2JA$P`%Q4``!,%9<N#-PD`/N2!1^_P3YP9Q2+X@T<%`"J$G>-"=")G
M@S<)`+F/`4>FA1<5```3!87(M>?B<*)T`GDA86_P+\XFA4[L[]#_FJJ)(H7O
MT'^:JIF)"4Z%[]#?FB*(EQ<``).'Y[(FAY<6``"3AD:S3H:)12J$[]#_PB)G
M@S<)`+F/`4>5XZ*%0G3B:>)PHG0">1<5```3!27"(6%O\$_((OA.[._0'\;O
MT-_%EW<``).'!Z])<8.X!P$#N(<!D'.4=YA[G'^F[LKJSN:&]J+REWD``(.Y
M2:8#LPD`&N8!0Q<3```3`\.^9`@^X9<7``"3AX>^*HF:X#[T%Q,``!,#HZ:7
M%P``DX>GO::%%Q4``!,%!:::Y(+HQNS"\++TMOBZ_#[X`OSO\,^*$<6#1P4`
M*H1CE`<VTN)6_EKZ7O9B\N_07XH!)>_0_[1C"@48@SH%`&.&"AA6A>_0WXD3
M%!4`!00BA>_0'XH#QPH`JHLBC"J*#<\7&P``$PN+M]J&(H:)15Z%[]`?LH4*
MXH9C<XP`HH:SAX9`B0=C\]<`MH<#QPH`>105C#Z4B0MI^Y,*@047%0``$P5%
MJBF@`[6*`*$*#<&FA>_P[X`JA&79@T<%`.W7[_#/BG71(H7OT+^@*H05X9,*
M`00#M`H`"<R#1P0`8X4'#B*%[_"/B&'I`[2*`*$*;?0BA>_0[_ZJBE*%[]!O
M_KN*J@";BDI`5H7OT(_^EQ<``).'1Y?2B!<8```3"*BL(H>7%@``DX:&K%:&
MB44JB^_0/Z:3!0`<6H7OT)^7_5=C&/4`[]#O_!Q!14=CGN<@9NZ3#($(YH5:
MA>_0GYLJA!GEZD>]9A%G]8]CAN<*EW<``(.W1X^#-@D`B&-:AQ<6```3!L:K
MB47OT+^>\FP!2C)G@[<)`+F/`4=CF`<NMG`6=/)Z4GNR>Q)\]F16:;9I4H46
M:G5A@H`BA>_0GY$JA*$*XPD%\#6W`40EMR)U(!`9R::%[^#?[@'%@T<%`)7C
M"&0A!'WU-47OT*_PJHLJBC5,-427&@``DXKJFQ,',`6-M>_0'XVJBF'=[]"/
M[1,4%0`%!#6]"EKOT*_KFP<%`.,7^O3J1Q,'`!R3]_<?XY#G]%:%[]#OZZ:%
M*HH7%0``$P5EI>_@W^>JA6,!!18#-0D`[_!OQBJ,8PH%%&*%[]!/Z)L+!0"-
M1V/8=P,3A<O_EQ4``).%I:)BE>_0C_H)[9%'8XC[')N'N__BEP/'!P"3!_`"
M8P_W&J:%%Q4``!,%A83OX/_A8P8%$(-'!0!C@@<0$P<``V..YPZ7%0``DX4%
MC!<5```3!06"[_!/E._03_0JB)<8``"3B.BKEP<``).'9WI:AY<6``"3AD:>
M5H:)15*%[]#_B?U414F7'```DXQLJ1<,```3#.QWEQL``).+ZYPEH._0S]\<
M06.7)P/OT"_O!20JB&;@HHCBAUJ'WH96AHE%4H7OT+^%DP4`'%*%[]`/]^,(
ME?Q:A>_0;_32A1<%```3!85P[_!/BU*%[_"?M_)L+;479P```S>G;X,V"0`(
M8Q<6```3!D:(6H>)1>_0#_\AM>_P'[4R9X.W"0"YCP%'8YT'#B*%%G2V</9D
M5FFV:75A;]"O\@,\"0!UM8%%8H7OT-^$JH3C#P7N[_#?G2J)XTH%[I,%9?\!
M1B:%[]`/ZI,+`0(91MZ%)H7OT"_VF4=C'/4(`E>W1T%#DX<',.,3]^P#UTL`
MD6>3AX=4XQSWZ@%&DP7I_":%[]!/YA,&@`+FA2:%[]"/\I,'@`)C'O4$EQ@`
M`).(R)9FB)<'``"3AR=E6H>7%@``DX8&B%:&B452A2,(`0KOT&_T[;T#.8D`
MXP$)Y$J%[]!OR(U'X_NGXG$5EQ4``).%I8-*E>_0#]OC$07B2HPQO1<5```3
M!<6"[_`_C6;N[]!O]M+B5OY:^E[V8O)F[N_0;_4Y<2+X%V0```,T9%I*\$[L
M!OPF]%+HLP=$`(1CDPE!`!=I```#.2E6@\<$"\Z%%P4``!,%15\#-PD`.N0!
M1Z.(]`KOX/^]&<4#1P4`DP<0`V,+]Q+O\._+LP=$`(1C)H6-1@5&EP4``).%
MY7[OT&_$JH0=P1QI,P=$``ACC&,7!@``$P;&?>_0S\.<:(QCW$43EY<"8T8'
M$+,'1`"(8XU&!4:7!0``DX4%?._0C\"JA!=J```3"JI8#<'.A1<%```3!>50
M[^#?M2J&><&<:#,'1``(8XQC[]#/OK,'1`"$8P5&EP4``).%A7@FA>_0;[*J
MA1<&```3!@9Y)H7OT&^\$I0<8,Z%%P4``!,%14NCB`<*[^#_L",XJ@`JA#G%
MDP4`'"*%[]#OSAL'%0"%1V/PYP+%1V,-]0"#-XH`JH8BAHQC%P4``!,%!7?O
MT(_3(F>#-PD`N8\!1['KXG!"=*)T`GGB:4)J(6&"@`,UB@#O\-^8(SBJ`"J$
M7?$7!0``$P4%<>_0#]"#1Q4`XXH'[-FU`S>*`)QH#&.(8^_@_\XUO[,'1`"(
M8^_0S\K]M>_0;]IY<2+P)NP&]!=D```#-*0\JH1,`!<%```3!>5''&`^Y(%'
M[^#_I`'-@T<%`(G+$P<``V.&YP"!Q(/'!`"9ZR)G'&"YCP%'H>^B<`)TXF1%
M88*`)H5*Z._PKZ"3!?`"*HGOT"_%&<$3"14`2H7OT&_!$4:7!0``DX4%4N_0
MCYT9P4)I=;\B9QQ@N8\!1Y'K`G1"::)P)H7B9$5A;^#?K4KH[]`OT$$1$P4`
M"`;D[]!OG[=V74PW=^EAMR5%9Y.%%3"&!C=6,A`&!PSADX;FSY=%``"#M<5!
M$P9F1Q,'!Q\,Y13I$.T8\2,T!0(C.`4"(RP%!J)@00&"@#EQ(O@F]$KP5N0&
M_$[L4N@8=9,7-@`4>;J7@A>!DS.WYP"JA+J6*%T35]8!-I><])CX,HDNA).*
MA`,Q[9,'\`-CW"<)&PD)_!M::0";"1H`F@FBF:*%$P8`!%:%[]#OI1,$!`0F
MA>_0C^KC%33_&QIJ`#L)24%*ALZ%5H7OT.^C(ZPD!^)P0G2B=`)YXFE":J)J
M(6&"@),)``2[AZE`OHEC2O8"&XH)`).*A`-2AJ*%5I7OT(^@O%P3!P`$NX;Y
M`+3<XY'F_":%.PDY05*4[]`/Y*VWLHGYMZ*)<;]Y<2+P)NQ2X`;T2NA.Y(.Y
MA0(3BH4#DP8`^!/6.0`3=O8#,P?*``.Y!0.3!Q8`(P#7`!,'@`,NA*J$!29C
M5_<2$P<`!!&?D48S!?H`8W77%(E'8WGW$F,4!Q(BA>_0;]T3!H`#@452A>_0
M;ZR35@D!$U>)`)/V]@^B!IM7B0$3=_</0@?5CQ-Y^0]B"=F/&]:)`9/6"0$"
M%K/G)P$3UXD`D_;V#Z(6T8\3=_</0A?5C^(9V8^SYS<!//@BA>_0;]<<8"*%
MX8,C@/0`'&#!@Z.`]``<8*&#(X'T`!Q@HX'T`!QDX8,C@O0`'&3!@Z."]``<
M9*&#(X/T`!QDHX/T`!QHX8,CA/0`'&C!@Z.$]``<:*&#(X7T`!QHHX7T`!QL
MX8,CAO0`'&S!@Z.&]``<;*&#(X?T`!QLHX?T`!QPX8,CB/0`''#!@Z.(]``<
M<*&#(XGT`!QPHXGT``)THG#B9$)IHFD":D5A;]"/D!,'@`,[!L=`@44S!?H`
M[]!OF\6](P`%`.&](P`%`*,`!0!Y%PD%XP4'[.VW(P`%`*,`!0`C`04`HP$%
M`'$7B4<1!>-E]^K1OY=F``"#ML8*;\!?_`$``@``````)7,O)7,```!$>6YA
M3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(``````$EN=&5R;F%L<SHZ4$%2.CI"
M3T]4`````"]P<F]C+W-E;&8O97AE``!E>&4``````"]P<F]C+R5I+R5S````
M```N`````````%!!4E]414U0``````````!005)?4%)/1TY!344`````.@``
M```````O`````````"5S)7,E<P``4$523#5,24(``````````%!%4DQ,24(`
M4$523#5/4%0``````````%!%4DQ)3P``4$%27TE.251)04Q)6D5$`%!!4E]3
M4$%73D5$``````!005)?0TQ%04X`````````4$%27T1%0E5'`````````%!!
M4E]#04-(10````````!005)?1TQ/0D%,7T1%0E5'``````````!005)?1TQ/
M0D%,7U1-4$1)4@````````!005)?5$U01$E2````````4$%27T=,3T)!3%]4
M14U0`%!!4E]'3$]"04Q?0TQ%04X``````````#$`````````;'-E96L@9F%I
M;&5D`````')E860@9F%I;&5D``````!,1%],24)205)97U!!5$@`4UE35$5-
M```O=&UP`````%5315(`````55-%4DY!344``````````"4P,G@`````<&%R
M+0`````E<R5S)7,E<P``````````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@
M<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@```````"5S.B!P
M<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO
M=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H```````!0051(````
M`'!A<FP`````+G!A<@````!S:&]R="!R96%D````````)7,E<V-A8VAE+25S
M)7,``"5S)7-T96UP+25U)7,````E<R5S=&5M<"TE=2TE=25S```````````8
M`````````'!E<FP`````,`````````!005(Z.E!A8VME<CHZ5D524TE/3@``
M```Q+C`V,P```%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y````
M```````E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O
M<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```````````M90```````"TM````
M````979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG
M"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E
M(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@)$9)3$5?;V9F<V5T7W-I>F4L
M("1C86-H95]N86UE7W-I>F4I.PI"14=)3B!["B1005)?34%'24,@/2`B7&Y0
M05(N<&U<;B(["B1&24Q%7V]F9G-E=%]S:7IE(#T@-#L@("`C('!A8VLH(DXB
M*0HD8V%C:&5?;F%M95]S:7IE(#T@-#`["B102UI)4%]-04=)0R`](")02UPP
M,#-<,#`T(CL*?0IS=6(@9FEN9%]P87)?;6%G:6,*>PIM>2`H)&9H*2`]($!?
M.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@)&)U9CL*;7D@)'-I
M>F4@/2`M<R`D9F@["FUY("1P;W,@/2`H)'-I>F4M,2D@+2`H)'-I>F4M,2D@
M)2`D8VAU;FM?<VEZ93L@("`@("`C($Y/5$4Z("1P;W,@:7,@82!M=6QT:7!L
M92!O9B`D8VAU;FM?<VEZ90IW:&EL92`H)'!O<R`^/2`P*2!["G-E96L@)&9H
M+"`D<&]S+"`P.PIR96%D("1F:"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG
M=&@H)%!!4E]-04=)0RD["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!
M4E]-04=)0RDI(#X](#`I('L*<F5T=7)N("1P;W,@*R`D:3L*?0HD<&]S("T]
M("1C:'5N:U]S:7IE.PI]"G)E='5R;B`M,3L*?0IM>2`H)'!A<E]T96UP+"`D
M<')O9VYA;64L($!T;7!F:6QE+"`E36]D=6QE0V%C:&4I.PI%3D0@>R!I9B`H
M)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER
M92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P
M9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T
M<RAQ<5M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(ETI.PI&:6QE.CI&
M:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@
M?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T
M96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE
M.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ
M0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L
M"E5.3$E.2R`]/B`P+`HI.PIM>2`D9FEL96YA;64@/2`D=&UP+3YF:6QE;F%M
M93L*<')I;G0@)'1M<"`\/"(N+BXB.PIX/3$[('=H:6QE(%L@7"1X("UL="`Q
M,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T
M96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q
M8`ID;VYE"G)M("<D9FEL96YA;64G"BXN+@IC;&]S92`D=&UP.PIC:&UO9"`P
M-S`P+"`D9FEL96YA;64["FUY("1C;60@/2`B)&9I;&5N86UE(#XO9&5V+VYU
M;&P@,CXF,2`F(CL*<WES=&5M*"1C;60I.PIO=71S*'%Q6U-P87=N960@8F%C
M:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@)&9I;&5N86UE
M72D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D
M969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI
M=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)7-Y
M<R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z
M("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\
M8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@
M/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA
M;64H*3L*;W5T<RAQ<5M<)'!R;V=N86UE(#T@(B1P<F]G;F%M92)=*3L*7W-E
M=%]P87)?=&5M<"@I.PIO=71S*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D14Y6
M>U!!4E]414U0?2)=*3L*;7D@*"1S=&%R=%]P;W,L("1S=&%R=%]O9E]&24Q%
M7W-E8W1I;VXI.PI-04=)0SH@>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U
M8B![?3L*=6YL97-S("AO<&5N(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE*2![
M"F]U=',H<7%;0V%N)W0@<F5A9"!F<F]M(&9I;&4@(B1P<F]G;F%M92)=*3L@
M(",@9&]N)W0@=7-E("0A(&AE<F4@87,@:70@<F5Q=6ER97,@17)R;F\N<&T*
M;&%S="!-04=)0SL*?0IM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H
M*E]&2"D["FEF("@D;6%G:6-?<&]S(#P@,"D@>PIO=71S*'%Q6T-A;B=T(&9I
M;F0@;6%G:6,@<W1R:6YG("(D4$%27TU!1TE#(B!I;B!F:6QE("(D<')O9VYA
M;64B72D["FQA<W0@34%'24,["GT*;W5T<R@B1F]U;F0@4$%2(&UA9VEC(&%T
M('!O<VET:6]N("1M86=I8U]P;W,B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@
M+2`D1DE,15]O9F9S971?<VEZ92`M(&QE;F=T:"@B7#!#04-(12(I+"`P.PIR
M96%D(%]&2"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&YE
M(")<,$-!0TA%(B`F)B`D8G5F(&YE(")<,$-,14%.(BD@>PIO=71S*").;R!C
M86-H92!M87)K97(@9F]U;F0B*3L*;&%S="!-04=)0SL*?0IO=71S*'%Q6T-A
M8VAE(&UA<FME<B`B)&)U9B(@9F]U;F1=*3L*<V5E:R!?1D@L("1M86=I8U]P
M;W,@+2`D1DE,15]O9F9S971?<VEZ92P@,#L*<F5A9"!?1D@L("1B=68L("1&
M24Q%7V]F9G-E=%]S:7IE.PIM>2`D;V9F<V5T(#T@=6YP86-K*").(BP@)&)U
M9BD["F]U=',H(D]F9G-E="!F<F]M('-T87)T(&]F($9)3$5S(&ES("1O9F9S
M970B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ
M92`M("1O9F9S970L(#`["B1S=&%R=%]O9E]&24Q%7W-E8W1I;VX@/2!T96QL
M(%]&2#L*;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,
M12(*=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T
M.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL
M;F%M92`]("1B=68["F]U=',H<7%;56YP86-K:6YG($9)3$4@(B1F=6QL;F%M
M92(N+BY=*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=
M>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@
M/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@
M)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII
M9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA
M;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1C<F,D97AT(BP@
M)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE
M?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA
M;65](#T@)&9U;&QN86UE.PI]"F5L<V4@>PHD36]D=6QE0V%C:&5[)&9U;&QN
M86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F
M=6QL;F%M92P*?3L*)')E<75I<F5?;&ES='LD9G5L;&YA;65]*RL["GT*<F5A
M9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E
M;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A
M)&UO9'5L93L*;7D@)&EN9F\@/2`D36]D=6QE0V%C:&5[)&UO9'5L97T["G)E
M='5R;B!U;FQE<W,@)&EN9F\["F1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U
M;&5].PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92([
M"FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN
M97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@
M(D-A;B=T(&-R96%T92!T96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D[
M"B1F:"T^<')I;G0H)&EN9F\M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I.PIR
M971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B
M)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*)&EN9F\M/GMF:6QE
M?2`]("1F:6QE;F%M93L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE;F%M
M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=.PIR971U
M<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;B=T(&9I
M;F0@;6]D=6QE("1M;V1U;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D
M97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*
M<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y
M;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE
M;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S
M("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2![
M"FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE
M;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@
M/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?
M;&ES='LD9FEL96YA;65].PI]"FEF("@D8G5F(&YE("102UI)4%]-04=)0RD@
M>PIO=71S*'%Q6TYO('II<"!F;W5N9"!A9G1E<B!&24Q%('-E8W1I;VX@:6X@
M9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#(#L*?0HD<W1A<G1?<&]S
M(#T@*'1E;&P@7T9(*2`M(#0[("`@("`@("`@("`@("`@(",@<W1A<G0@;V8@
M>FEP"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H
M+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C
M('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0II
M9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS
M)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O
M7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I
M9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;
M,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?
M4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@
M8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%2
M1U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*
M:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I
M9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q
M("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q
M("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N
M9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]
M("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE
M;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D
M:64@<7%;0V%N)W0@;W!E;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*96QS:68@
M*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6
M*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6
M>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*
M)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ
M1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T
M($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E
M($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E
M<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII
M9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R
M(&]R(&1I92!Q<5M#86XG="!F:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB
M;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN
M97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@
M07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I
M;F<@>FEP(&%R8VAI=F4@(B1P87(B73L*?0IM>2`E;65T85]P87(@/2!D;R![
M"FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!
M+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S
M+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]
M"GT["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D<&@L("<\.G)A=R<L
M("1P87(@;W(@9&EE('%Q6T-A;B=T(')E860@<&%R(&9I;&4@(B1P87(B.B`D
M(5T["FUY("1B=68["G)E860@)'!H+"`D8G5F+"`T.PID:64@<7%;(B1P87(B
M(&ES(&YO="!A('!A<B!F:6QE72!U;FQE<W,@)&)U9B!E<2`D4$M:25!?34%'
M24,["F-L;W-E("1P:#L*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@
M24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/
M.CI&:6QE.CI/7U)$5U(H*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L
M"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F:6QE("(D;W5T(CH@)"%=.PHD
M9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(["FEF
M("AD969I;F5D("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI('L*<F5A9"!?1D@L
M("1L;V%D97(L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VX["GT@96QS92!["FQO
M8V%L("0O(#T@=6YD968["B1L;V%D97(@/2`\7T9(/CL*?0II9B`H(21%3E9[
M4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I
M('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R
M.CI0;V13=')I<"T^87!P;'DH7"1L;V%D97(L("0P*3L*?0HD9F@M/G!R:6YT
M*"1L;V%D97(I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG(&QO861E<B!T;R`B
M)&]U="(Z("0A73L*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y
M.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D[
M"G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.
M+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N
M9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O
M;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F
M;W)E86-H($!I;F,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN
M84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D
M;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@("`C
M(%A86"!L:6)?97AT('9S(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A8V@@
M;7D@)&ME>2`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE
M*3L*:68@*&1E9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H
M97LD:V5Y?2DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE
M;'-E('L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\
M7EQ1)&1I<EQ%+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@
M)#$I.PIL87-T.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ
M*21\*2!["FEF("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I
M;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D9&ER
M+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S
M=#L*?0I]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT(&EF
M("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D
M9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M0
M86-K:6YG($9)3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M
M97T@.B`D9FEL92DI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*
M)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O(#T@
M=6YD968["F]P96X@;7D@)'1H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@<7%;
M0V%N)W0@<F5A9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@/"1T:#X["F-L
M;W-E("1T:#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E
M;G0L("(\96UB961D960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-
M?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E
M<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L
M("1N86UE*3L*?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T
M:"@D;F%M92D@*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII
M<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.)RP@
M;&5N9W1H*"1C;VYT96YT*2DL"B1C;VYT96YT*0IO<B!D:64@<7%;17)R;W(@
M=W)I=&EN9R!E;6)E9&1E9"!&24Q%('1O("(D;W5T(CH@)"%=.PIO=71S*'%Q
M6U=R:71T96X@87,@(B1N86UE(ETI.PI]"GT*:68@*"1Z:7`I('L*)'II<"T^
M=W)I=&54;T9I;&5(86YD;&4H)&9H*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+
M"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('II<"!P87)T(&]F("(D;W5T(ET[
M"GT*:68@*"1M971A7W!A<GMC;&5A;GTI('L*)&9H+3YP<FEN="@B7#!#3$5!
M3B(I.PI]"F5L<V4@>PII9B`H(61E9FEN960@)&-A8VAE7VYA;64I('L*;7D@
M)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["G-E96L@)&9H+"`P+"`P.PHD
M8W1X+3YA9&1F:6QE*"1F:"D["G-E96L@)&9H+"`P+"`R.PHD8V%C:&5?;F%M
M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M92`]('-U8G-T<B`D
M8V%C:&5?;F%M92P@,"P@)&-A8VAE7VYA;65?<VEZ93L*)&-A8VAE7VYA;64@
M+CT@(EPP(B!X("@D8V%C:&5?;F%M95]S:7IE("T@;&5N9W1H("1C86-H95]N
M86UE*3L*)&9H+3YP<FEN="@D8V%C:&5?;F%M92P*(EPP0T%#2$4B*3L*?0IM
M>2`D;V9F<V5T(#T@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I.PHD9F@M
M/G!R:6YT*'!A8VLH)TXG+"`D;V9F<V5T*2P*)%!!4E]-04=)0RD["B1F:"T^
M8VQO<V4@;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@=')A:6QE<B!O9B`B)&]U
M="(Z("0A73L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL
M97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U
M:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E
M<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@
M)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*
M)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E
M;B@I(&9A:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M
M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@D>FEP+3YR
M96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z
M.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R
M8VAI=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ
M92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2
M.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*;W5T<R@B17AT<F%C=&EN
M9R!Z:7`N+BXB*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S
M:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E
M<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E
M8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN
M97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD
M0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@
M)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E
M8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF
M("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S
M<V5D4VEZ92@I*2!["F]U=',H<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M92(@
M<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B72D["GT@
M96QS92!["F]U=',H<7%;17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B
M)&1E<W1?;F%M92(N+BY=*3L**"1M96UB97(M/F5X=')A8W14;T9I;&5.86UE
M9"@D9&5S=%]N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I
M92!Q<5M%<G)O<B!E>'1R86-T:6YG('II<"!M96UB97(@=&\@(B1D97-T7VYA
M;64B73L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X
M(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI
M('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB
M+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P
M<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*
M+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T
M*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*
M<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L
M("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<
M+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T
M:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H
M(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR
M97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S
M=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER
M92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR
M97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q
M=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z
M.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U
M:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M
M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I
M9V5S=#HZ4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR
M97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R
M:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER
M92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E
M<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T[
M"F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L
M('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@
M<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A
M;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@
M*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^
M("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@
M;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$
M25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I
M"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A
M;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH
M)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@
M9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97
M:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD
M=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[
M55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*;7D@)'-T
M;7!D:7(@/2`B)'!A=&@D<WES>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@
M)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FUY("1C86-H95]D
M:7(["FEF("@D14Y6>U!!4E]#3$5!3GTI('L*)&-A8VAE7V1I<B`](")T96UP
M+20D(CL*?0IE;'-E('L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M
M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PII9B`H
M*&UY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@D9F@I*2`^/2`P*2![
M"G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L
M96YG=&@H(EPP0T%#2$4B*2P@,#L*;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L
M(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*
M<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE
M;F=T:"@B7#!#04-(12(I"BT@)&-A8VAE7VYA;65?<VEZ92P@,#L*<F5A9"`D
M9F@L("1B=68L("1C86-H95]N86UE7W-I>F4["B1B=68@/7X@<R]<,"\O9SL*
M)&-A8VAE7V1I<B`](")C86-H92TD8G5F(CL*?0I]"F-L;W-E("1F:#L*?0II
M9B`H(21C86-H95]D:7(I('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*)$5.
M5GM005)?0TQ%04Y](#T@,3L*?0HD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U]
M)&-A8VAE7V1I<B(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PHD14Y6>U!!4E]4
M14U0?2`]("1S=&UP9&ER.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%
M3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*
M<W5B(%]S879E7V%S('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]
M($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S
M("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD
M)"(["FUY("1F:#L**&]P96X@)&9H+"`G/CIR87<G+"`D=&5M<&YA;64I"B8F
M("AP<FEN="`D9F@@)&-O;G1E;G1S*0HF)B`H8VQO<V4@)&9H*0IO<B!D:64@
M<7%;17)R;W(@=W)I=&EN9R`B)'1E;7!N86UE(CH@)"%=.PIC:&UO9"`D;6]D
M92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA
M;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N
M("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D
M("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^
M("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P
M.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.
M5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G
M;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`K(#$I.PI]
M"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@
M)'-Y<WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D
M<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G
M;F%M921S>7-[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D<WES>U]E>&5].PIR
M971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421S>7-[<&%T
M:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[
M4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^
M(',O7%$D<WES>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1S
M>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB*2P@;&%S="D*:68@+7,@
M(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](CL**"@D<')O
M9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II
M9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I
M>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'
M3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/"`P
M*2!["B1P<F]G;F%M92`]("(N)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0IM
M>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D
M*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W
M9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_
M/5PN7"X_7%$D<WES>U]D96QI;7U<12DO)'!W9"1S>7-[7V1E;&EM?2\["B1%
M3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET
M7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*
M<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]
M"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'
M3D%-12`I("D@>PID96QE=&4@)$5.5GLB4$%27R1?(GT["GT*9F]R("AQ=R\@
M5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R)005)?)%\B?2`]
M("1%3E9[(E!!4E]'3$]"04Q?)%\B?2!I9B!E>&ES=',@)$5.5GLB4$%27T=,
M3T)!3%\D7R)].PI]"FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.
M5GM005)?0TQ%04Y].PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T
M.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92![
M"G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N
M9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O
M;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE
M>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]
M"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"90
M05(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7%;
M<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.
M;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&Y="G5N;&5S<R`M92`D<')O9VYA
M;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?
M5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T52
M4D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)2
M3U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I
M9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@!435!$25(``%1%35!$25(`5$5-
M4`````!435```````(FKS>\`````<&5R;'AS:2YC``````````!#04-(10``
M`1L#.^P````<````N)#__WP&``!$DO__!`$``/R2__\8`0``9J7__U`!```2
MIO__O`$``&RF___H`0``=*?__T`"``#.I___9`(``+2H__^D`@``;JK__Q`#
M``"6JO__)`,``%RK__]@`P``7JO__W0#```TK?__R`,``%:M___H`P``6*[_
M_RP$``"PL?__8`0``/ZQ__^$!```0K+__YP$``!FL___[`0``'ZS__\(!0``
M0+3__UP%``!&N?___`4``/:Z__\T!@``FKO__[`&``#NN___T`8``,J\__\(
M!P``?+[__T`'````````$``````````#>E(``7P!`1L-`@`0````&````#B1
M__\B``````<!`#0````L````W)'__VH2````1`[`!5B(!($"B0:2"),*E`P#
M,!(*P43(1,E$TD331-1$#@!""P``:````&0````.I/__K`````!"#D!$@0*(
M!$R6$%*2"),*E`QFB0:5#F;)0M)"TT+40M5"UD+!1,A"#@!"#D"!`H@$B0:2
M"),*E`R5#I804,G2T]35UD26$$+61)((DPJ4#)801M)"TT+40M8`*````-``
M``!.I/__6@````!"#K`!1H@$B0:!`@)&"L%"R$+)0@X`0@L```!4````_```
M`'RD__\(`0```$(.P`%$DPJ!`EB(!$;(4,%"TT(.`$(.P`&!`H@$DPI$B0:2
M"'*4#`)8U%0*R$+)0M)""U*4#$C(R=+42(@$B0:2")0,````(````%0!```L
MI?__6@````!"#A!"B`1*@0)HR$+!7@X`````/````'@!``!BI?__Y@````!"
M#E!$E0Y:#M`@B`2)!I((DPJ4#($"`GH*#E!"P4+(0LE"TD+30M1"U4(.`$(+
M`&@```"X`0``"*;__[H!````0@YP5(@$B0:2")0,@0*3"I80EQ("T`K!0LA"
MR4+20M-"U$+60M="#@!""W"5#I@4F18"6`K50MA"V40+5M78V425#I@4F19&
MU=C91I4.F!29%D;50MA"V0```!`````D`@``5J?__R@`````````.````#@"
M``!JI___Q@````!"#E!$B092#M!`@0*(!)((DPJ4#`*8"@Y00L%$R$+)0M)"
MTT+40@X`0@L`$````'0"``#TI___`@````````!0````B`(``.*G___6`0``
M`$8.\`%F#O`AB`2)!I((F!2!`I,*E`R5#I80EQ*9%IH8`F(*#O`!0L%"R$+)
M0M)"TT+40M5"UD+70MA"V4+:0@X`0@L<````W`(``&2I__\B`````$(.$$B(
M!($"4,A"P4(.`$````#\`@``9JG__P(!````0@XP4@ZP()((@0*(!(D&`J@*
M#C!"P4+(0LE"TD(.`$(+5@H.,$+!0LA"R4+22@X`1`L`,````$`#```DJO__
M6`,```!"#D!*B`2)!I((DPJ!`@,*`PK(0L%"R4+20M-2#@!$"P```"````!T
M`P``2*W__TX`````0@X@1(@$@0)Z"L%"R$(.`$(+`!0```"8`P``<JW__T0`
M````0@Y@0H$2`$P```"P`P``GJW__R0!````0@YP1(@$7`[P@`23"I0,F1:!
M`HD&D@B5#I80EQ*8%`+""@YP0L%"R$+)0M)"TT+40M5"UD+70MA"V4(.`$(+
M&``````$``!RKO__&`````!"#A!"@0)0P4(.`%`````<!```;J[__\(`````
M0@Y`1HD&D@B!`FB(!$;(6,%"R4+20@X`1`Y`@0*(!(D&D@A$DPH"1,A"TT+!
M0LE"TDH.`$0.0($"B0:2"$2(!),*`)P```!P!```W*[__P8%````2@[P`EJ)
M!I((DPJ!`H@$`G"4#)4.EA"7$I@4`R0!F18"/-E2"L%"R$+50M9"UT+80LE"
MTD+31-1"#@!""P)>F18#4`'98M35UM?85LA"P4+)0M)"TT(.`$0.\`*!`H@$
MB0:2"),*E`R5#I80EQ*8%)D6`]X`V4*9%D34U=;7V-E,E`R5#I80EQ*8%)D6
M```T````$`4``$*S__^P`0```$(.0$*(!%*2"),*@0*)!I0,`T8!"L%"R$+)
M0M)"TT+40@X`0@L``$0```!(!0``NK3__Z0`````0@XP1H@$B0:!`@)""L%"
MR$+)0@X`0@M$D@AL"M)""TS(0M)"P43)0@X`1`XP@0*(!(D&0I((`#````"0
M!0``-(K__XH!````0@Y@3($"B0:(!)((DPH##@$*P4+(0LE"TT320@X`0@L`
M```<````Q`4``.*T__]4`````$(.$$:!`@)(P4(.`````#0```#D!0``%K7_
M_]P`````0@Y`3H@$B0:2")4.@0*3"I0,`G8*P4+(0LE"TD+30M1"U4(.`$(+
M-````!P&``"ZM?__L@$```!"#C!,B`2)!I0,@0*2"),*`TP!"LA"P4+)0M)"
MTT+40@X`1`L````0````5`8``#2W__\,````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````!
M`````````/D"`````````0`````````$`P````````$`````````#@,`````
M```=`````````+@$````````(`````````!XJP```````"$`````````"```
M```````9`````````("K````````&P`````````(`````````!H`````````
MB*L````````<``````````@`````````!`````````#8`@```````/7^_V\`
M````^`4````````%`````````&`0````````!@````````#H!@````````H`
M````````[@0````````+`````````!@`````````%0``````````````````
M``,`````````P*T````````"`````````%@%````````%``````````'````
M`````!<`````````B!@````````'`````````'@6````````"`````````!H
M!P````````D`````````&``````````>``````````@`````````^___;P``
M```!```(`````/[__V\`````&!8```````#___]O``````(`````````\/__
M;P````!.%0```````/G__V\`````"P``````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````/__________``````````#@'0```````.`=
M````````X!T```````#@'0```````.`=````````X!T```````#@'0``````
M`.`=````````X!T```````#@'0```````.`=````````X!T```````#@'0``
M`````.`=````````X!T```````#@'0```````.`=````````X!T```````#@
M'0```````.`=````````X!T```````#@'0```````.`=````````X!T`````
M``#@'0```````.`=````````X!T```````#@'0```````.`=````````X!T`
M``````#@'0```````.`=````````X!T```````#@'0```````.`=````````
MX!T```````#@'0```````.`=````````X!T```````#@'0```````.`=````
M````X!T```````#@'0```````.`=````````X!T```````#@'0```````.`=
M````````X!T```````#@'0```````.`=````````X!T```````#@'0``````
M`.`=````````X!T```````#@'0```````.`=````````X!T```````"0JP``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````"E!!4BYP;0H`````````````````````````
M````````````````````````````````````````````````````````````
M1T-#.B`H4U5312!,:6YU>"D@,3,N,RXP`$%2````<FES8W8``4@````$$`5R
M=C8T:3)P,5]M,G`P7V$R<#%?9C)P,E]D,G`R7V,R<#!?>FEC<W(R<#!?>FEF
M96YC96DR<#!?>FUM=6PQ<#```"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+F=N
M=2YB=6EL9"UI9``N;F]T92Y!0DDM=&%G`"YG;G4N:&%S:``N9'EN<WEM`"YD
M>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N
M<F5L82YP;'0`+G1E>'0`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M
M90`N<')E:6YI=%]A<G)A>0`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9'EN
M86UI8P`N9V]T`"YD871A`"YB<W,`+F-O;6UE;G0`+G)I<V-V+F%T=')I8G5T
M97,`````````````````````````````````````````````````````````
M````````````````````````````````````"P````$````"`````````'`"
M````````<`(````````A`````````````````````0``````````````````
M`!,````'`````@````````"4`@```````)0"````````)```````````````
M``````0````````````````````F````!P````(`````````N`(```````"X
M`@```````"`````````````````````$````````````````````.`````4`
M```"`````````-@"````````V`(````````@`P````````8`````````"```
M```````$`````````#0```#V__]O`@````````#X!0```````/@%````````
M[``````````&``````````@````````````````````^````"P````(`````
M````Z`8```````#H!@```````'@)````````!P````(````(`````````!@`
M````````1@````,````"`````````&`0````````8!````````#N!```````
M`````````````0```````````````````$X```#___]O`@````````!.%0``
M`````$X5````````R@`````````&``````````(``````````@````````!;
M````_O__;P(`````````&!8````````8%@```````&``````````!P````(`
M```(````````````````````:@````0````"`````````'@6````````>!8`
M```````0`@````````8`````````"``````````8`````````'0````$````
M0@````````"(&````````(@8````````6`4````````&````%0````@`````
M````&`````````!Y`````0````8`````````X!T```````#@'0```````+`#
M```````````````````0`````````!``````````?@````$````&````````
M`)`A````````D"$```````#0+0``````````````````!```````````````
M`````(0````!`````@````````!@3P```````&!/````````=T$`````````
M``````````@```````````````````",`````0````(`````````V)``````
M``#8D````````.P````````````````````$````````````````````F@``
M``$````"`````````,B1````````R)$```````!H!@``````````````````
M"````````````````````*0````0`````P````````!XJP```````'B;````
M````"`````````````````````$`````````"`````````"S````#@````,`
M````````@*L```````"`FP````````@````````````````````(````````
M``@`````````OP````\````#`````````(BK````````B)L````````(````
M````````````````"``````````(`````````,L````&`````P````````"0
MJP```````)";````````,`(````````'``````````@`````````$```````
M``#4`````0````,`````````P*T```````#`G0```````$`"````````````
M```````(``````````@`````````V0````$````#``````````"P````````
M`*````````!0````````````````````"````````````````````-\````(
M`````P````````!0L````````%"@````````*`````````````````````@`
M``````````````````#D`````0```#````````````````````!0H```````
M`!D````````````````````!``````````$`````````[0````,``'``````
M````````````````::````````!3`````````````````````0``````````
M``````````$````#`````````````````````````+R@````````_P``````
:``````````````$`````````````````````
